// FILENAME:	DM_Bloody_Brunch.cs
//
// AUTHORS:  	Chupie Doll & Youth in Asia
//------------------------------------------------------------------------------

$missionName = "OCC_Delta_Construct";


exec("multiplayerStdLib.cs");
exec("DMstdLib.cs");

$yellowHealRate = $blueHealRate = $redHealRate = $purpleHealRate = 750;
$padWaitTime = 15;
$zenWaitTime = 60;

$killPoints 	= 3;
$deathPoints 	= 2;
$occPoints		= 2;		// Points per 30 seconds of occupation
$occKillPoints	= 7;		// Extra Points for killing the occupier (added to $killPoints)
$fortowner = "";

// move the map
$server::HudMapViewOffsetX = -605;
$server::HudMapViewOffsetY = -765;

function player::onAdd(%this)
{
   say(%this, 0, "Welcome to " @ $missionName @ "!  <F5>NOTE:<F0> Read the <F2>?<F0> tab for rules.");
}

function setDefaultMissionOptions()
{
	$server::TeamPlay = false;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

   // what can the client choose for a team
	$server::AllowTeamRed = true;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = false;

   // what can the server admin choose for available teams
   $server::disableTeamRed = false;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = false;
}


function onMissionStart()
{
	initGlobalVars();

	$redBonus = 0;
	$blueBonus = 0;

	$redTK = 0;
	$blueTK = 0;

	$redoccKills = 0;
	$blueoccKills = 0;

	venusSounds();
}

function initGlobalVars()
{
   $scoringFreeze = false;
   
   %playerCount = playerManager::getPlayerCount();
	// clear all points for the players
   for (%p = 0; %p < %playerCount; %p++)
	{
		%player = playerManager::getPlayerNum(%p);
      %player.occKills = 0;
      %player.occPoints = 0;
   }
}

function onMissionLoad(){
   cdAudioCycle("Purge", "Terror", "Watching"); 
}

function setRules()
{
      %rules = "<F2>GAME TYPE: \n<F0>Occupation.\n\n"   @        
               "<tIDMULT_TDM_MAPNAME>"    @ 
               $missionName             @
               "\n\n<F2>RULES/OBJECTIVES:\n" @
               "<F0>1) Occupy the Delta Construct and destroy the enemy.\n" @
               "2) Turrets are indestructible: Therefore, destroy the Occupier of the Construct!\n"@
               "3) Only one player can occupy the Construct at a time.\n\n"@
               "<tIDMULT_TDM_SCORING_1>"  @ 
               "<F0>Kills are worth " @ $killPoints @ " points, deaths are worth -" @ $deathPoints @ " points.\n" @
               "Occupiers of the Construct receive " @ $occPoints @ " points every 30 seconds.\n" @
               "Killing the Occupier of the Construct is worth " @ $occKillPoints @ " points.\n\n" @
               "<F2>SERVER RULES/INFORMATION:\n"      @ 
               "<F0>1) All weapons are LEGAL.\n" @
		   "2) Padkilling is LEGAL, particularly if you heal on an enemies pad.\n" @
		   "3) Complaining about items 1 or 2 is ILLEGAL!  Deal with it!  Adapt!  Destroy!\n" @
		   "4) This map was made by Temujin.  You can download it from his website\n" @
 		   "   at http://www6.50megs.com/temujin.  Also at that site is a comprehensive\n" @
		   "   StarSiege training manual and Temujins skin collections.\n\n";

   setGameInfo(%rules);      
}

// setup the rules - this has to be called after the definition of setRules
setRules();

function vehicle::onAdd(%vehicleId)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicleId);

	%team = getTeam(%vehicleId);
	if(%team == *IDSTR_TEAM_RED) %pcolor = "RED";
	if(%team == *IDSTR_TEAM_BLUE) %pcolor = "BLUE";

	%player.name = getHUDName(%vehicleId);
	if(!%player.occPoints) %player.occPoints = 0;
	if(!%player.occKills) %player.occKills = 0;

	// Ensure that occPoints and occKills stay with the player if they switch teams...

	if(%pcolor != %player.color) {
	   %player.color = %pcolor;
	   if(%pcolor == "RED") {
  		$redBonus += %player.occPoints;
		$blueBonus -= %player.occPoints;
		$red_occKills += %player.occKills;
		$blue_occKills -= %player.occKills;
		}
	   else {
		$redBonus -= %player.occPoints;
		$blueBonus += %player.occPoints;
		$redoccKills -= %player.occKills;
		$blueoccKills += %player.occKills;
	   }
	}
}


// Fortification Functionality
//------------------------------------------------------------------------------



function Fortify::trigger::OnEnter(%this, %object)
{
	if($fortowner && %object!= $fortowner) {
		say("everybody", 0, getHudName(%object) @ " is ejected from the Delta Construct!", "sfx_had.WAV");
		rejectvehicle(%object);
		return 0;
		}
	$fortowner = %object;
      say("everybody", 0, getHudName($fortowner)@ " has occupied the Delta Construct!", "sfx_siren.WAV");
	giveTurretsToThisGuy(%object);
	schedule("retractBridge();", 0.2);
}

function Fortify::trigger::OnContact(%this, %object)
{
      %player = playerManager::vehicleIdToPlayerNum(%object);
	%team = getTeam(%object);
	if( %object != $fortowner ) return 0; // shouldn't happen, but just in case
	%player.occPoints = %player.occPoints + $occPoints;
	if(%team == *IDSTR_TEAM_RED) $redBonus = $redBonus + $occPoints;
	if(%team == *IDSTR_TEAM_BLUE) $blueBonus = $blueBonus + $occPoints;
}

function Fortify::trigger::OnLeave(%this, %object)
{
	if( %object == $fortowner ) schedule("neutralizefort();", 2);
}

function vehicle::onDestroyed(%destroyed, %destroyer)
{
   if( %destroyed == $fortowner ) schedule("neutralizefort();", 2);
	
   %team = getTeam(%destroyer);

   if(getHUDName(%destroyer) == "Delta Construct") {
	if(%team == *IDSTR_TEAM_RED) {
	   $redBonus = $redBonus + 3;
	   $redTK += 1;
	   }
	else if(%team == *IDSTR_TEAM_BLUE) {
	   $blueBonus = $blueBonus + 3;
	   $blueTK += 1;
	   }
   }
   
   if(%destroyed != %destroyer) {
	if(%destroyed == $fortowner) {
         %player = playerManager::vehicleIdToPlayerNum(%destroyer);
   	   %player.occKills += 1;
	   if(%team == *IDSTR_TEAM_RED) $redoccKills += 1;
	   else if(%team == *IDSTR_TEAM_BLUE) $blueoccKills += 1;
	   }
	}

   // Taken from DMStdLib.cs 

   // left over from missionStdLib.cs
   vehicle::onDestroyedLog(%destroyed, %destroyer);
   
   // this is weird but %destroyer isn't necessarily a vehicle
   %message = getFancyDeathMessage(getHUDName(%destroyed), getHUDName(%destroyer));
   if(%message != "")
   {
      say( 0, 0, %message);
   }
   
   // enforce the rules
   if($server::TeamPlay == true)
   {
      if((getTeam(%destroyed) == getTeam(%destroyer)) &&
         (%destroyed != %destroyer) ) {
         antiTeamKill(%destroyer);
      }
   }  
}

function neutralizefort()
{
	if($fortowner == "") return 0;
      say("everybody", 0, "The Delta Construct is unoccupied!", "sfx_cybrid_alarm.WAV");
	$fortowner = "";
	schedule("makeTurretsNeutral();", 2);
	extendBridge();
}

function retractBridge() 
{
	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeN");

      schedule("moveBridge("@%target@", -585, 918,  -4);", 0.15 );
      schedule("moveBridge("@%target@", -590, 906,  -9);", 0.3 );
      schedule("moveBridge("@%target@", -595, 893, -15);", 0.45 );
      schedule("moveBridge("@%target@", -605, 878, -22);", 0.6 );
      schedule("moveBridge("@%target@", -615, 863, -30);", 0.75 );
      schedule("moveBridge("@%target@", -628, 848, -39);", 0.9 );
      schedule("moveBridge("@%target@", -647, 833, -49);", 1.05 );
      schedule("moveBridge("@%target@", -670, 822, -60);", 1.2 );
      schedule("moveBridge("@%target@", -700, 814, -73);", 1.35 );
      schedule("moveBridge("@%target@", -730, 810, -90);", 1.5 );

	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeS");

      schedule("moveBridge("@%target@", -945, 918,  4);", 0.15 );
      schedule("moveBridge("@%target@", -940, 906,  9);", 0.3 );
      schedule("moveBridge("@%target@", -935, 893, 15);", 0.45 );
      schedule("moveBridge("@%target@", -925, 878, 22);", 0.6 );
      schedule("moveBridge("@%target@", -915, 863, 30);", 0.75 );
      schedule("moveBridge("@%target@", -902, 848, 39);", 0.9 );
      schedule("moveBridge("@%target@", -883, 833, 49);", 1.05 );
      schedule("moveBridge("@%target@", -860, 822, 60);", 1.2 );
      schedule("moveBridge("@%target@", -830, 814, 73);", 1.35 );
      schedule("moveBridge("@%target@", -800, 810, 90);", 1.5 );	

	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeE");

      schedule("moveSideBridge("@%target@", -425, 918,  4);", 0.15 );
      schedule("moveSideBridge("@%target@", -430, 906,  9);", 0.3 );
      schedule("moveSideBridge("@%target@", -435, 893, 15);", 0.45 );
      schedule("moveSideBridge("@%target@", -445, 878, 22);", 0.6 );
      schedule("moveSideBridge("@%target@", -455, 863, 30);", 0.75 );
      schedule("moveSideBridge("@%target@", -468, 848, 39);", 0.9 );
      schedule("moveSideBridge("@%target@", -487, 833, 49);", 1.05 );
      schedule("moveSideBridge("@%target@", -510, 822, 60);", 1.2 );
      schedule("moveSideBridge("@%target@", -540, 814, 73);", 1.35 );
      schedule("moveSideBridge("@%target@", -570, 810, 90);", 1.5 );

	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeW");

      schedule("moveSideBridge("@%target@", -785, 918,  -4);", 0.15 );
      schedule("moveSideBridge("@%target@", -780, 906,  -9);", 0.3 );
      schedule("moveSideBridge("@%target@", -775, 893, -15);", 0.45 );
      schedule("moveSideBridge("@%target@", -765, 878, -22);", 0.6 );
      schedule("moveSideBridge("@%target@", -755, 863, -30);", 0.75 );
      schedule("moveSideBridge("@%target@", -742, 848, -39);", 0.9 );
      schedule("moveSideBridge("@%target@", -723, 833, -49);", 1.05 );
      schedule("moveSideBridge("@%target@", -700, 822, -60);", 1.2 );
      schedule("moveSideBridge("@%target@", -670, 814, -73);", 1.35 );
      schedule("moveSideBridge("@%target@", -640, 810, -90);", 1.5 );	
}

function extendBridge() 
{
	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeN");

      schedule("moveBridge("@%target@", -585, 928,   0);", 1.0 );
      schedule("moveBridge("@%target@", -585, 918,  -4);", 0.9 );
      schedule("moveBridge("@%target@", -590, 906,  -9);", 0.8 );
      schedule("moveBridge("@%target@", -595, 893, -15);", 0.7 );
      schedule("moveBridge("@%target@", -605, 878, -22);", 0.6 );
      schedule("moveBridge("@%target@", -615, 863, -30);", 0.5 );
      schedule("moveBridge("@%target@", -628, 848, -39);", 0.4 );
      schedule("moveBridge("@%target@", -647, 833, -49);", 0.3 );
      schedule("moveBridge("@%target@", -670, 822, -60);", 0.2 );
      schedule("moveBridge("@%target@", -700, 814, -73);", 0.1 );
 	
	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeS");

      schedule("moveBridge("@%target@", -945, 928,  0);", 1.0 );
      schedule("moveBridge("@%target@", -945, 918,  4);", 0.9 );
      schedule("moveBridge("@%target@", -940, 906,  9);", 0.8 );
      schedule("moveBridge("@%target@", -935, 893, 15);", 0.7 );
      schedule("moveBridge("@%target@", -925, 878, 22);", 0.6 );
      schedule("moveBridge("@%target@", -915, 863, 30);", 0.5 );
      schedule("moveBridge("@%target@", -902, 848, 39);", 0.4 );
      schedule("moveBridge("@%target@", -883, 833, 49);", 0.3 );
      schedule("moveBridge("@%target@", -860, 822, 60);", 0.2 );
      schedule("moveBridge("@%target@", -830, 814, 73);", 0.1 );

	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeE");

      schedule("moveSideBridge("@%target@", -425, 928,  0);", 1.0 );
      schedule("moveSideBridge("@%target@", -425, 918,  4);", 0.9 );
      schedule("moveSideBridge("@%target@", -430, 906,  9);", 0.8 );
      schedule("moveSideBridge("@%target@", -435, 893, 15);", 0.7 );
      schedule("moveSideBridge("@%target@", -445, 878, 22);", 0.6 );
      schedule("moveSideBridge("@%target@", -455, 863, 30);", 0.5 );
      schedule("moveSideBridge("@%target@", -468, 848, 39);", 0.4 );
      schedule("moveSideBridge("@%target@", -487, 833, 49);", 0.3 );
      schedule("moveSideBridge("@%target@", -510, 822, 60);", 0.2 );
      schedule("moveSideBridge("@%target@", -540, 814, 73);", 0.1 );

	%target = getObjectId("MissionGroup\\Construct\\DrawBridgeW");

      schedule("moveSideBridge("@%target@", -785, 928,   0);", 1.0 );	
      schedule("moveSideBridge("@%target@", -785, 918,  -4);", 0.9 );
      schedule("moveSideBridge("@%target@", -780, 906,  -9);", 0.8 );
      schedule("moveSideBridge("@%target@", -775, 893, -15);", 0.7 );
      schedule("moveSideBridge("@%target@", -765, 878, -22);", 0.6 );
      schedule("moveSideBridge("@%target@", -755, 863, -30);", 0.5 );
      schedule("moveSideBridge("@%target@", -742, 848, -39);", 0.4 );
      schedule("moveSideBridge("@%target@", -723, 833, -49);", 0.3 );
      schedule("moveSideBridge("@%target@", -700, 822, -60);", 0.2 );
      schedule("moveSideBridge("@%target@", -670, 814, -73);", 0.1 );
}

function moveBridge(%bridge, %y, %z, %xrot)
{
	setPosition(%bridge, -605, %y, %z, 0, %xrot);
}

function moveSideBridge(%bridge, %x, %z, %xrot)
{
	setPosition(%bridge, %x, -765, %z, 90, %xrot);
}

function rejectvehicle(%object)
{
      %chx = -605 - getPosition(%object,x);
      %chy = -765 - getPosition(%object,y);

	%x = -605 - 3 * %chx;
	%y = -765 - 3 * %chy;
      %z = getPosition(%object,z) + 5;
	
      setPosition(%object, %x, %y, %z);

      %player = playerManager::vehicleIdToPlayerNum(%object);
      say(%player, 0, "sfx_cybrid_alarm.WAV");
}



// Flame teleporters...



function BlueTele::trigger::OnEnter(%this, %object)
{
	%x = randomInt( -805, -405);
	%y = randomInt( 385, 785);

	setPosition(%object, %x, %y, 960);
}

function RedTele::trigger::OnEnter(%this, %object)
{
	%x = randomInt( -805, -405);
	%y = randomInt( -2315, -1915);

	setPosition(%object, %x, %y, 960);
}

function WestTele::trigger::OnEnter(%this, %object)
{
	%x = randomInt( -1045, -975);
	%y = randomInt( -800, -730);

	setPosition(%object, %x, %y, 970);
}

function EastTele::trigger::OnEnter(%this, %object)
{
	%x = randomInt( -235, -165);
	%y = randomInt( -800, -730);

	setPosition(%object, %x, %y, 970);
}

function RTeleUp::structure::OnScan(%this, %object)
{
	%x = randomInt( -660, -550);
	%y = randomInt( -1595, -1590);

	setPosition(%object, %x, %y, 1025);
}

function BTeleUp::structure::OnScan(%this, %object)
{
	%x = randomInt( -660, -550);
	%y = randomInt( 60, -65);

	setPosition(%object, %x, %y, 1025);
}

function RTeleDown::structure::OnScan(%this, %object)
{
	%x = randomInt( -618, -592);
	%y = randomInt( -1613, -1577);

	setPosition(%object, %x, %y, 945);
}

function BTeleDown::structure::OnScan(%this, %object)
{
	%x = randomInt( -618, -592);
	%y = randomInt( 47, 83);

	setPosition(%object, %x, %y, 945);
}

function NorthScan::structure::OnScan(%this, %object)
{
	%x = getPosition( %object, x );
	%y = getPosition( %object, y );

	%endX = randomInt( -630, -580 );
	%endY = randomInt( -445, -345 );

	moveIt( %object, %x, %y, %endX, %endY );
}

function SouthScan::structure::OnScan(%this, %object)
{
	%x = getPosition( %object, x );
	%y = getPosition( %object, y );

	%endX = randomInt( -630, -580 );
	%endY = randomInt( -1185, -1085 );

	moveIt( %object, %x, %y, %endX, %endY );
}

function EastScan::structure::OnScan(%this, %object)
{
	%x = getPosition( %object, x );
	%y = getPosition( %object, y );

	%endX = randomInt( -285, -185 );
	%endY = randomInt( -790, -740 );

	moveIt( %object, %x, %y, %endX, %endY );
}

function WestScan::structure::OnScan(%this, %object)
{
	%x = getPosition( %object, x );
	%y = getPosition( %object, y );

	%endX = randomInt( -1025, -925 );
	%endY = randomInt( -790, -740 );

	moveIt( %object, %x, %y, %endX, %endY );
}

function moveIt(%object, %startX, %startY, %endX, %endY)
{
	%x = %startX - %endX;
	%y = %startY - %endY;

      %player = playerManager::vehicleIdToPlayerNum(%object);
      say("everybody", 0, "sfx_teleport.WAV");

	%xinc = %x/10;
	%yinc = %y/10;

      schedule("subMove("@%object@", "@ (%startX - (1*%xinc)) @", "@ (%startY - (1*%yinc)) @");", 0.1 );
      schedule("subMove("@%object@", "@ (%startX - (2*%xinc)) @", "@ (%startY - (2*%yinc)) @");", 0.2 );
      schedule("subMove("@%object@", "@ (%startX - (3*%xinc)) @", "@ (%startY - (3*%yinc)) @");", 0.3 );
      schedule("subMove("@%object@", "@ (%startX - (4*%xinc)) @", "@ (%startY - (4*%yinc)) @");", 0.4 );
      schedule("subMove("@%object@", "@ (%startX - (5*%xinc)) @", "@ (%startY - (5*%yinc)) @");", 0.5 );
      schedule("subMove("@%object@", "@ (%startX - (6*%xinc)) @", "@ (%startY - (6*%yinc)) @");", 0.6 );
      schedule("subMove("@%object@", "@ (%startX - (7*%xinc)) @", "@ (%startY - (7*%yinc)) @");", 0.7 );
      schedule("subMove("@%object@", "@ (%startX - (8*%xinc)) @", "@ (%startY - (8*%yinc)) @");", 0.8 );
      schedule("subMove("@%object@", "@ (%startX - (9*%xinc)) @", "@ (%startY - (9*%yinc)) @");", 0.9 );
      schedule("subMove("@%object@", "@   %endX   @", "@   %endY   @");", 1.0 );
}

function subMove(%object, %x, %y)
{
	setPosition(%object, %x, %y, 965);
}



// Turret Code
// -----------------------------------------------------------------------------------



function giveTurretsToThisGuy(%vehicleId){
	%team = getTeam(%vehicleId);
	setTeam("MissionGroup\\Construct\\T1", %team);
	setTeam("MissionGroup\\Construct\\T2", %team);
	setTeam("MissionGroup\\Construct\\T3", %team);
	setTeam("MissionGroup\\Construct\\T4", %team);
	setTeam("MissionGroup\\Construct\\T5", %team);

	order("MissionGroup\\Construct", Shutdown, false);
}

function makeTurretsNeutral(){
	healObject("MissionGroup\\Construct", 25000);
	setTeam("MissionGroup\\Construct\\T1", 0);
	setTeam("MissionGroup\\Construct\\T2", 0);
	setTeam("MissionGroup\\Construct\\T3", 0);
	setTeam("MissionGroup\\Construct\\T4", 0);
	setTeam("MissionGroup\\Construct\\T5", 0);

	order("MissionGroup\\Construct", Shutdown, true);	
}



//------------------------------------------------------------------------------
// scoreboard 



function getPlayerScore(%a)
{
   %p = (getAdjKills(%a)*$killPoints)-(getDeaths(%a)*$deathPoints)+(%a.occKills*$occKillPoints)+%a.occPoints;
   return (%p);
}

function getAdjKills(%a)
{
   return (getKills(%a) - %a.occKills);
}

function getOccPoints(%a)
{
	return(%a.occPoints);
}

function getOccKills(%a)
{
	return(%a.occKills);
}

function getTeamTurretKills(%team)
{
	%teamname = getTeamNameFromTeamId(%team);
	if(%teamname == *IDSTR_TEAM_RED) 
	{
		return($redTK);
	}
	if(%teamname == *IDSTR_TEAM_BLUE) 
	{
		return($blueTK);
	}

	return 0;
}

function getTeamScore(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) 
   {
	%p = $redBonus+(getAdjTeamKills(%team)*$killPoints)-(getTeamDeaths(%team)*$deathPoints)+($redoccKills*$occKillPoints);
	return(%p);
   }
   if(%teamname == *IDSTR_TEAM_BLUE) 
   {
	%p = $blueBonus+(getAdjTeamKills(%team)*$killPoints)-(getTeamDeaths(%team)*$deathPoints)+($blueoccKills*$occKillPoints);
	return(%p);
   }

   return 0;
} 

function getAdjTeamKills(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) return (getTeamKills(%team) - $redoccKills);
   if(%teamname == *IDSTR_TEAM_BLUE) return (getTeamKills(%team) - $blueoccKills);
   else return 0;
}

function getTeamOccKills(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) return $redoccKills;
   if(%teamname == *IDSTR_TEAM_BLUE) return $blueoccKills;
   else return 0;
}

function initScoreBoard()
{
   deleteVariables("$ScoreBoard::PlayerColumn*");
   deleteVariables("$ScoreBoard::TeamColumn*");

   if($server::TeamPlay == "True")	
   {
	   // Player ScoreBoard column headings
	   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_TEAM;
	   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SQUAD;
	   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_SCORE;
	   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_KILLS;
	   $ScoreBoard::PlayerColumnHeader5 = *IDMULT_SCORE_DEATHS;
	   $ScoreBoard::PlayerColumnHeader6 = "Occ. Kills";
	   $ScoreBoard::PlayerColumnHeader7 = "Occ. Points";

	   // Player ScoreBoard column functions
	   $ScoreBoard::PlayerColumnFunction1 = "getTeam";
	   $ScoreBoard::PlayerColumnFunction2 = "getSquad";
	   $ScoreBoard::PlayerColumnFunction3 = "getPlayerScore";
	   $ScoreBoard::PlayerColumnFunction4 = "getKills";
	   $ScoreBoard::PlayerColumnFunction5 = "getDeaths";
	   $ScoreBoard::PlayerColumnFunction6 = "getOccKills";
	   $ScoreBoard::PlayerColumnFunction7 = "getOccPoints";
   }
   else
   {
       // Player ScoreBoard column headings
	   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_SQUAD;
	   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SCORE;
	   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_KILLS;
	   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_DEATHS;

	   // Player ScoreBoard column functions
	   $ScoreBoard::PlayerColumnFunction1 = "getSquad";
	   $ScoreBoard::PlayerColumnFunction2 = "getPlayerScore";
	   $ScoreBoard::PlayerColumnFunction3 = "getKills";
	   $ScoreBoard::PlayerColumnFunction4 = "getDeaths";
   }

   // Team ScoreBoard column headings
   $ScoreBoard::TeamColumnHeader1 = *IDMULT_SCORE_SCORE;
   $ScoreBoard::TeamColumnHeader2 = *IDMULT_SCORE_PLAYERS;
   $ScoreBoard::TeamColumnHeader3 = *IDMULT_SCORE_KILLS;
   $ScoreBoard::TeamColumnHeader4 = *IDMULT_SCORE_DEATHS;
   $ScoreBoard::TeamColumnHeader5 = "Turret Kills";
   $ScoreBoard::TeamColumnHeader6 = "Occ. Kills";

   // Team ScoreBoard column functions
   $ScoreBoard::TeamColumnFunction1 = "getTeamScore";
   $ScoreBoard::TeamColumnFunction2 = "getNumberOfPlayersOnTeam";
   $ScoreBoard::TeamColumnFunction3 = "getAdjTeamKills";
   $ScoreBoard::TeamColumnFunction4 = "getTeamDeaths";
   $ScoreBoard::TeamColumnFunction5 = "getTeamTurretKills";
   $ScoreBoard::TeamColumnFunction6 = "getTeamOccKills";

   // tell server to process all the scoreboard definitions defined above
   serverInitScoreBoard();
}

